sturdy.numpy.dataset


def-splittercljmacro

(def-splitter fname src-tag)

Generate a function that splits a column-major flat primitive array into a vector of per-column primitive arrays (each length = rows).

Generate a function that splits a column-major flat primitive array
into a vector of per-column primitive arrays (each length = rows).
sourceraw docstring

def-transposercljmacro

(def-transposer fname src-tag array-ctor aset-fn)

Define a transpose fn for a primitive array type. src-tag is one of: bytes, shorts, ints, longs, floats, doubles array-ctor is e.g. float-array aset-fn is e.g. aset-float

Define a transpose fn for a primitive array type.
src-tag is one of: bytes, shorts, ints, longs, floats, doubles
array-ctor is e.g. float-array
aset-fn is e.g. aset-float
sourceraw docstring

dtype->splitterclj

(dtype->splitter dtype)
source

dtype->transposerclj

(dtype->transposer dtype)
source

npy->datasetclj

(npy->dataset path)
source

split-byteclj

(split-byte src22785 rows22786 cols22787)
source

split-doubleclj

(split-double src22778 rows22779 cols22780)
source

split-floatclj

(split-float src22771 rows22772 cols22773)
source

split-intclj

(split-int src22799 rows22800 cols22801)
source

split-longclj

(split-long src22806 rows22807 cols22808)
source

split-shortclj

(split-short src22792 rows22793 cols22794)
source

transpose-byteclj

(transpose-byte src22718 rows22719 cols22720)
source

transpose-doubleclj

(transpose-double src22707 rows22708 cols22709)
source

transpose-floatclj

(transpose-float src22696 rows22697 cols22698)
source

transpose-intclj

(transpose-int src22740 rows22741 cols22742)
source

transpose-longclj

(transpose-long src22751 rows22752 cols22753)
source

transpose-shortclj

(transpose-short src22729 rows22730 cols22731)
source

cljdoc builds & hosts documentation for Clojure/Script libraries